@@ -1,7 +1,7 @@
 /****************************************************************************
 *                                                                           *
 *   GlobalHotkeys plugin for Kadu                                           *
-*   Copyright (C) 2008-2011  Piotr Dąbrowski ultr@ultr.pl                   *
+*   Copyright (C) 2008-2012  Piotr Dąbrowski ultr@ultr.pl                   *
 *                                                                           *
 *   This program is free software: you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
@@ -28,7 +28,6 @@
 
 #include "buddies/buddy-manager.h"
 #include "buddies/group-manager.h"
-#include "chat/message/pending-messages-manager.h"
 #include "chat/chat-manager.h"
 #include "chat/recent-chat-manager.h"
 #include "core/core.h"
@@ -38,13 +37,15 @@
 #include "gui/widgets/status-menu.h"
 #include "gui/windows/add-buddy-window.h"
 #include "gui/windows/kadu-window.h"
+#include "gui/windows/modules-window.h"
+#include "gui/windows/multilogon-window.h"
 #include "gui/windows/search-window.h"
 #include "gui/windows/your-accounts.h"
 #include "file-transfer/file-transfer-manager.h"
 #include "icons/icons-manager.h"
+#include "message/message-manager.h"
 #include "misc/path-conversion.h"
 #include "notify/notification-manager.h"
-#include "plugins/plugins-manager.h"
 #include "status/status-container-manager.h"
 #include "status/status-type.h"
 #include "status/status-type-manager.h"
@@ -125,53 +126,39 @@ void Functions::functionShowHideKadusMainWindow( ConfHotKey *confhotkey )
 void Functions::functionOpenIncomingChatWindow( ConfHotKey *confhotkey )
 {
 	Q_UNUSED( confhotkey );
-	if( PendingMessagesManager::instance()->hasPendingMessages() )
+	// activate opened window with new unread message(s)
+	foreach( ChatWidget *chatwidget, ChatWidgetManager::instance()->chats() )
 	{
-		// open window for pending message(s)
-		ChatWidgetManager::instance()->openPendingMessages( true );
-		// activate it
-		QWidget *win = ChatWidgetManager::instance()->chats().values().last();  // last created chat widget
-		win = win->window();
-		_activateWindow( win );
-	}
-	else
-	{
-		// show window with new unread message(s)
-		foreach( ChatWidget *chatwidget, ChatWidgetManager::instance()->chats() )
+		if( chatwidget->chat().unreadMessagesCount() > 0 )
 		{
-			if( chatwidget->newMessagesCount() > 0 )
-			{
-				chatwidget->show();
-				_activateWindow( chatwidget->window() );
-				// done - only one window
-				break;
-			}
+			chatwidget->activate();
+			// done - only one window
+			return;
 		}
 	}
+	// open window for unread message(s)
+	if( MessageManager::instance()->hasUnreadMessages() )
+	{
+		ChatWidget *chatwidget = ChatWidgetManager::instance()->byChat( MessageManager::instance()->unreadMessage().messageChat(), true );
+		chatwidget->activate();
+	}
 }
 
 
 void Functions::functionOpenAllIncomingChatWindows( ConfHotKey *confhotkey )
 {
 	Q_UNUSED( confhotkey );
-	// open all windows for pending message(s)
-	while( PendingMessagesManager::instance()->hasPendingMessages() )
+	// open all windows for unread message(s)
+	while( MessageManager::instance()->hasUnreadMessages() )
 	{
-		// open the window
-		ChatWidgetManager::instance()->openPendingMessages( true );
-		// activate it
-		QWidget *win = ChatWidgetManager::instance()->chats().values().last();  // last created chat widget
-		win = win->window();
-		_activateWindow( win );
+		ChatWidget *chatwidget = ChatWidgetManager::instance()->byChat( MessageManager::instance()->unreadMessage().messageChat(), true );
+		chatwidget->activate();
 	}
-	// show all windows with new unread message(s)
+	// activate all opened windows with new unread message(s)
 	foreach( ChatWidget *chatwidget, ChatWidgetManager::instance()->chats() )
 	{
-		if( chatwidget->newMessagesCount() > 0 )
-		{
-			chatwidget->show();
-			_activateWindow( chatwidget->window() );
-		}
+		if( chatwidget->chat().unreadMessagesCount() > 0 )
+			chatwidget->activate();
 	}
 }
 
@@ -345,10 +332,11 @@ void Functions::functionChangeDescription( ConfHotKey *confhotkey )
 			return;
 		}
 	}
-	StatusContainer *statuscontainer =
-		( StatusContainerManager::instance()->statusContainers().count() == 1 ) ?
-		StatusContainerManager::instance()->statusContainers()[0] : StatusContainerManager::instance();
-	ChooseDescription *dialog = ChooseDescription::showDialog( statuscontainer );
+	QList<StatusContainer*> statuscontainers =
+		( StatusContainerManager::instance()->statusContainers().count() == 1 )
+			? ( QList<StatusContainer*>() << StatusContainerManager::instance()->statusContainers()[0] )
+			: StatusContainerManager::instance()->subStatusContainers();
+	ChooseDescription *dialog = ChooseDescription::showDialog( statuscontainers );
 	new GlobalWidgetManager( dialog );
 	// global data
 	GlobalHotkeys::instance()->SHOWNGLOBALWIDGET = dialog;
@@ -381,6 +369,13 @@ void Functions::functionFileTransfersWindow( ConfHotKey *confhotkey )
 }
 
 
+void Functions::functionMultilogonWindow( ConfHotKey *confhotkey )
+{
+	Q_UNUSED( confhotkey );
+	MultilogonWindow::instance()->show();
+}
+
+
 void Functions::functionConfigurationWindow( ConfHotKey *confhotkey )
 {
 	Q_UNUSED( confhotkey );
@@ -400,5 +395,5 @@ void Functions::functionAccountManagerWindow( ConfHotKey *confhotkey )
 void Functions::functionPluginsWindow( ConfHotKey *confhotkey )
 {
 	Q_UNUSED( confhotkey );
-	PluginsManager::instance()->showWindow( NULL, false );
+	ModulesWindow::show();
 }
