@@ -1,7 +1,7 @@
 /****************************************************************************
 *                                                                           *
 *   GlobalHotkeys plugin for Kadu                                           *
-*   Copyright (C) 2008-2011  Piotr Dąbrowski ultr@ultr.pl                   *
+*   Copyright (C) 2008-2012  Piotr Dąbrowski ultr@ultr.pl                   *
 *                                                                           *
 *   This program is free software: you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
@@ -31,13 +31,13 @@
 #include <QString>
 #include <QStringList>
 #include <QTimer>
+#include <QVector>
 #include <QX11Info>
 
 #include "buddies/buddy.h"
 #include "buddies/buddy-manager.h"
 #include "buddies/buddy-preferred-manager.h"
 #include "buddies/group-manager.h"
-#include "chat/message/pending-messages-manager.h"
 #include "chat/chat-manager.h"
 #include "chat/recent-chat-manager.h"
 #include "core/core.h"
@@ -51,8 +51,8 @@
 #include "gui/windows/add-buddy-window.h"
 #include "gui/windows/kadu-window.h"
 #include "gui/windows/your-accounts.h"
-#include "file-transfer/file-transfer-manager.h"
 #include "icons/icons-manager.h"
+#include "message/message-manager.h"
 #include "misc/path-conversion.h"
 #include "notify/notification-manager.h"
 #include "status/status-container-manager.h"
@@ -119,6 +119,7 @@ GlobalHotkeys::GlobalHotkeys()
 	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Buddies"           ), QT_TRANSLATE_NOOP( "@default", "Add a new buddy"                    ), "AddANewBuddy"               , "functionAddANewBuddy"                         );
 	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Buddies"           ), QT_TRANSLATE_NOOP( "@default", "Search for buddy"                   ), "SearchForBuddy"             , "functionSearchForBuddy"                       );
 	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Windows shortcuts" ), QT_TRANSLATE_NOOP( "@default", "File transfers window"              ), "FileTransfersWindow"        , "functionFileTransfersWindow"                  );
+	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Windows shortcuts" ), QT_TRANSLATE_NOOP( "@default", "Multilogon window"                  ), "MultilogonWindow"           , "functionMultilogonWindow"                     );
 	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Windows shortcuts" ), QT_TRANSLATE_NOOP( "@default", "Configuration window"               ), "ConfigurationWindow"        , "functionConfigurationWindow"                  );
 	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Windows shortcuts" ), QT_TRANSLATE_NOOP( "@default", "Account manager window"             ), "AccountManagerWindow"       , "functionAccountManagerWindow"                 );
 	new ConfHotKey( this, QT_TRANSLATE_NOOP( "@default", "Windows shortcuts" ), QT_TRANSLATE_NOOP( "@default", "Plugins window"                     ), "PluginsWindow"              , "functionPluginsWindow"                        );
@@ -447,7 +448,8 @@ void GlobalHotkeys::processConfBuddiesShortcut( ConfBuddiesShortcut *confbuddies
 			contactset.insert( BuddyPreferredManager::instance()->preferredContact( buddy, accounts.first() ) );
 		}
 		Chat chat = ChatManager::instance()->findChat( contactset, true );
-		ChatWidgetManager::instance()->openPendingMessages( chat, true );
+		ChatWidget *chatwidget = ChatWidgetManager::instance()->byChat( chat, true );
+		chatwidget->activate();
 	}
 	else
 	{
@@ -515,19 +517,19 @@ void GlobalHotkeys::processConfBuddiesMenu( ConfBuddiesMenu *confbuddiesmenu )
 		// for each currently open chat
 		foreach( ChatWidget *chatwidget, ChatWidgetManager::instance()->chats() )
 		{
-			QList<Contact> contacts = chatwidget->chat().contacts().toContactList();
+			QVector<Contact> contacts = chatwidget->chat().contacts().toContactVector();
 			menu->add( contacts );
 		}
 	}
 	// add chats with pending messages to the menu
-	if( confbuddiesmenu->pendingChats() && ( PendingMessagesManager::instance()->hasPendingMessages() ) )
+	if( confbuddiesmenu->pendingChats() && ( MessageManager::instance()->hasUnreadMessages() ) )
 	{
 		QList<ContactSet> contactsetlist;
-		// for each pending message
-		foreach( Message message, PendingMessagesManager::instance()->pendingMessages() )
+		// for each unread message
+		foreach( Message message, MessageManager::instance()->allUnreadMessages() )
 		{
 			ContactSet contactset = message.messageChat().contacts();
-			menu->add( contactset.toContactList() );
+			menu->add( contactset.toContactVector() );
 		}
 	}
 	// add recently closed chats to the menu
@@ -536,14 +538,14 @@ void GlobalHotkeys::processConfBuddiesMenu( ConfBuddiesMenu *confbuddiesmenu )
 		// for each recently closed chat
 		foreach( Chat chat, RecentChatManager::instance()->recentChats() )
 		{
-			menu->add( chat.contacts().toContactList() );
+			menu->add( chat.contacts().toContactVector() );
 		}
 	}
 	// add online contatcts to the menu
 	if( confbuddiesmenu->onlineBuddies() )
 	{
-		QStringList onlinestatusgroups;
-		onlinestatusgroups << "Online" << "Away" << "Invisible";
+		QList<StatusTypeGroup> onlinestatusgroups;
+		onlinestatusgroups << StatusTypeGroupOnline << StatusTypeGroupAway << StatusTypeGroupInvisible;
 		foreach( Buddy buddy, BuddyManager::instance()->items() )
 		{
 			Contact contact = BuddyPreferredManager::instance()->preferredContact( buddy );
@@ -603,6 +605,8 @@ void GlobalHotkeys::processConfBuddiesMenu( ConfBuddiesMenu *confbuddiesmenu )
 		menu->remove( buddydisplay );
 	// set one item per buddy
 	menu->setOneItemPerBuddy( confbuddiesmenu->oneItemPerBuddy() );
+	// set always showing contact identifier
+	menu->setAlwaysShowContactIdentifier( confbuddiesmenu->alwaysShowContactIdentifier() );
 	// set stateless sorting
 	menu->setSortStatelessBuddies(         confbuddiesmenu->sortStatelessBuddies()         );
 	menu->setSortStatelessBuddiesByStatus( confbuddiesmenu->sortStatelessBuddiesByStatus() );
