@@ -1,7 +1,7 @@
 /****************************************************************************
 *                                                                           *
 *   MessagesSplitter plugin for Kadu                                        *
-*   Copyright (C) 2011  Piotr Dąbrowski ultr@ultr.pl                        *
+*   Copyright (C) 2011-2012  Piotr Dąbrowski ultr@ultr.pl                   *
 *                                                                           *
 *   This program is free software: you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
@@ -21,9 +21,12 @@
 
 
 
+#include <unistd.h>
+
 #include <QApplication>
 #include <QTextDocumentFragment>
 
+#include "accounts/account.h"
 #include "configuration/configuration-file.h"
 #include "gui/widgets/chat-edit-box.h"
 #include "gui/widgets/chat-widget-manager.h"
@@ -40,11 +43,6 @@
 
 
 
-MessagesSplitter *messagessplitter;
-
-
-
-
 int MessagesSplitter::init( bool firstLoad )
 {
 	Q_UNUSED( firstLoad );
